@@ -17,8 +17,10 @@ from __future__ import absolute_import
 import os
 import random
 import socket
+import sys
 import threading
 import time
+import traceback
 import types
 
 from datetime import datetime
@@ -114,6 +116,7 @@ class MetlogClient(object):
     Client class encapsulating metlog API, and providing storage for default
     values for various metlog call settings.
     """
+    # envelope version, only changes when the message format changes
     env_version = '0.8'
 
     def __init__(self, sender, logger, severity=6,
@@ -183,19 +186,26 @@ class MetlogClient(object):
                 return
         self.sender.send_message(msg)
 
-    def add_method(self, name, method, override=False):
+    def add_method(self, method, override=False):
         """
         Add a custom method to the MetlogClient instance.
 
-        :param name: Name to use for the method.
         :param method: Callable that will be used as the method.
-        :param override: Set this to True if you really want to
-                         override an existing method.
+        :param override: Set this to the method name you want to
+                         override. False indicates no override will
+                         occur.
         """
         assert isinstance(method, types.FunctionType)
-        if not override and hasattr(self, name):
+
+        # Obtain the metlog name directly from the method
+        name = method.metlog_name
+        if isinstance(override, basestring):
+            name = override
+
+        if override is False and hasattr(self, name):
             msg = "The name [%s] is already in use" % name
             raise SyntaxError(msg)
+
         self._dynamic_methods[name] = method
         meth = types.MethodType(method, self, self.__class__)
         setattr(self, name, meth)
@@ -297,27 +307,50 @@ class MetlogClient(object):
         self.metlog('counter', timestamp, logger, severity, payload, fields)
 
     # Standard Python logging API emulation
-    def debug(self, msg):
+    def _oldstyle(self, severity, msg, *args, **kwargs):
+        """Do any necessary string formatting and then generate the msg"""
+        # if `args` is a mapping then extract it
+        if (len(args) == 1 and hasattr(args[0], 'keys')
+            and hasattr(args[0], '__getitem__')):
+            args = args[0]
+        msg = msg % args
+        exc_info = kwargs.get('exc_info', False)
+        if exc_info:
+            if not isinstance(exc_info, tuple):
+                exc_info = sys.exc_info()
+            tb_lines = traceback.format_exception(exc_info[0], exc_info[1],
+                                                  exc_info[2])
+            s = ''.join(tb_lines)
+            if s[-1:] == '\n':
+                s = s[:-1]
+            if msg[-1:] != '\n':
+                msg = msg + '\n'
+            try:
+                msg = msg + s
+            except UnicodeError:
+                msg = msg + s.decode(sys.getfilesystemencoding())
+        self.metlog(type='oldstyle', severity=severity, payload=msg)
+
+    def debug(self, msg, *args, **kwargs):
         """ Log a DEBUG level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.DEBUG, payload=msg)
+        self._oldstyle(SEVERITY.DEBUG, msg, *args, **kwargs)
 
-    def info(self, msg):
-        """ Log a INFO level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.INFORMATIONAL,
-                    payload=msg)
+    def info(self, msg, *args, **kwargs):
+        """ Log an INFO level message """
+        self._oldstyle(SEVERITY.INFORMATIONAL, msg, *args, **kwargs)
 
-    def warn(self, msg):
+    def warn(self, msg, *args, **kwargs):
         """ Log a WARN level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.WARNING, payload=msg)
+        self._oldstyle(SEVERITY.WARNING, msg, *args, **kwargs)
 
-    def error(self, msg):
-        """ Log a ERROR level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.ERROR, payload=msg)
+    def error(self, msg, *args, **kwargs):
+        """ Log an ERROR level message """
+        self._oldstyle(SEVERITY.ERROR, msg, *args, **kwargs)
 
-    def exception(self, msg):
-        """ Log a ALERT level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.ALERT, payload=msg)
+    def exception(self, msg, exc_info=True, *args, **kwargs):
+        """ Log an ALERT level message """
+        self._oldstyle(SEVERITY.ALERT, msg, exc_info=exc_info, *args, **kwargs)
 
-    def critical(self, msg):
+    def critical(self, msg, *args, **kwargs):
         """ Log a CRITICAL level message """
-        self.metlog(type='oldstyle', severity=SEVERITY.CRITICAL, payload=msg)
+        self._oldstyle(SEVERITY.CRITICAL, msg, *args, **kwargs)
