@@ -12,7 +12,11 @@
 #   Rob Miller (rmiller@mozilla.com)
 #
 # ***** END LICENSE BLOCK *****
+import socket
+import os
+
 from metlog.config import client_from_dict_config
+from metlog.client import MetlogClient
 from metlog.decorators import incr_count
 from metlog.decorators import timeit
 from metlog.holder import CLIENT_HOLDER
@@ -94,9 +98,14 @@ class TestDecoratorArgs(DecoratorTestBase):
         eq_(len(msgs), 1)
 
         expected = {'severity': 2, 'timestamp': 0,
-                    'fields': {'name': 'qdo.foo'},
+                    'fields': {'name': 'qdo.foo',
+                        'rate': 1.0,
+                        },
                     'logger': 'somelogger', 'type': 'counter',
-                    'payload': '5', 'env_version': '0.8'}
+                    'payload': '5', 'env_version': MetlogClient.env_version,
+                    'metlog_hostname': socket.gethostname(),
+                    'metlog_pid': os.getpid(),
+                    }
         eq_(msgs[0], expected)
 
     @raises(TypeError)
@@ -120,9 +129,13 @@ class TestDecoratorArgs(DecoratorTestBase):
 
         expected = {'severity': 5, 'timestamp': 8231,
                     'fields': {'anumber': 42, 'rate': 7,
-                               'name': 'qdo.timeit', 'atext': 'foo'},
+                               'name': 'qdo.timeit', 'atext': 'foo',
+                               },
                     'logger': 'timeit_logger', 'type': 'timer',
-                    'payload': '0', 'env_version': '0.8'}
+                    'payload': '0', 'env_version': MetlogClient.env_version,
+                    'metlog_hostname': socket.gethostname(),
+                    'metlog_pid': os.getpid(),
+                    }
         eq_(msgs[0], expected)
 
     @raises(TypeError)
